:mod:`routes` -- Routes module 
================================================

.. automodule:: routes

Module Contents
---------------

.. currentmodule:: routes

.. autofunction:: request_config

.. autoclass:: Mapper
    :members: connect, create_regs, generate, match, redirect, resource, routematch

.. autoclass:: URLGenerator

.. autofunction:: url_for

.. autofunction:: redirect_to

.. currentmodule:: routes.mapper
.. autofunction:: strip_slashes

.. currentmodule:: routes.middleware

.. autoclass:: RoutesMiddleware
